@@ -14,8 +14,9 @@
 # Author(s):
 #             Gunnar Wrobel <wrobel@gentoo.org>
 #
+'''Handles different storage files.'''
 
-__version__ = "$Id: db.py 218 2006-07-25 12:31:27Z wrobel $"
+__version__ = "$Id: db.py 238 2006-09-05 21:40:31Z wrobel $"
 
 #===============================================================================
 #
@@ -45,7 +46,12 @@ class DB(Overlays):
 
         self.path = config['local_list']
 
-        Overlays.__init__(self, [config['local_list'], ])
+        if config['nocheck']:
+            ignore = 2
+        else:
+            ignore = 1
+
+        Overlays.__init__(self, [config['local_list'], ], ignore)
 
         OUT.debug('DB handler initiated', 6)
 
@@ -53,39 +59,44 @@ class DB(Overlays):
         '''
         Add an overlay to the local list of overlays.
 
-        >>> write2 = os.tmpnam()
-        >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> m = MakeConf(here + '/tests/testfiles/make.conf')
-        >>> m.path = write2
-        >>> m.write()
-
         >>> write = os.tmpnam()
+        >>> write2 = os.tmpnam()
         >>> write3 = os.tmpnam()
         >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> config = {'local_list' : 
+        >>> config = {'local_list' :
         ...           here + '/tests/testfiles/global-overlays.xml',
         ...           'make_conf' : write2,
+        ...           'nocheck'    : True,
         ...           'storage'   : write3}
+
+        >>> here = os.path.dirname(os.path.realpath(__file__))
         >>> a = DB(config)
         >>> config['local_list'] = write
         >>> b = DB(config)
         >>> OUT.color_off()
-        >>> b.add(a.select('wrobel-stable')) #doctest: +ELLIPSIS
-        * Running command "/usr/bin/rsync -rlptDvz --progress --delete --delete-after --timeout=180 --exclude="distfiles/*" --exclude="local/*" --exclude="packages/*" rsync://gunnarwrobel.de/wrobel-stable/* /tmp/file.../wrobel-stable"...
 
-        >>> c = Overlays([write, ])
-        >>> c.overlays.keys()
-        [u'wrobel-stable']
-        
-        >>> m = MakeConf(write2)
-        >>> m.overlays #doctest: +ELLIPSIS
-        ['/usr/portage/local/ebuilds/broken', '/usr/portage/local/ebuilds/testing', '/usr/portage/local/ebuilds/stable', '/usr/portage/local/kolab2', '/usr/portage/local/gentoo-webapps-overlay/experimental', '/usr/portage/local/gentoo-webapps-overlay/production-ready', '/tmp/file.../wrobel-stable']
+        >>> m = MakeConf(config, b.overlays)
+        >>> m.path = write2
+        >>> m.write()
+
+        Commented out since it needs network access:
+
+        # >>> b.add(a.select('wrobel-stable')) #doctest: +ELLIPSIS
+        # * Running command "/usr/bin/rsync -rlptDvz --progress --delete --delete-after --timeout=180 --exclude="distfiles/*" --exclude="local/*" --exclude="packages/*" "rsync://gunnarwrobel.de/wrobel-stable/*" "/tmp/file.../wrobel-stable""...
+        # >>> c = Overlays([write, ])
+        # >>> c.overlays.keys()
+        # [u'wrobel-stable']
+
+        # >>> m = MakeConf(config, b.overlays)
+        # >>> [i.name for i in m.overlays] #doctest: +ELLIPSIS
+        # [u'wrobel-stable']
 
 
-        >>> os.unlink(write)
+        # >>> os.unlink(write)
         >>> os.unlink(write2)
         >>> import shutil
-        >>> shutil.rmtree(write3)
+
+        # >>> shutil.rmtree(write3)
         '''
 
         if overlay.name not in self.overlays.keys():
@@ -93,8 +104,8 @@ class DB(Overlays):
             if result == 0:
                 self.overlays[overlay.name] = overlay
                 self.write(self.path)
-                make_conf = MakeConf(self.config['make_conf'])
-                make_conf.add(path([self.config['storage'], overlay.name]))
+                make_conf = MakeConf(self.config, self.overlays)
+                make_conf.add(overlay)
             else:
                 overlay.delete(self.config['storage'])
                 raise Exception('Adding the overlay failed!')
@@ -106,55 +117,64 @@ class DB(Overlays):
         '''
         Add an overlay to the local list of overlays.
 
-        >>> write2 = os.tmpnam()
-        >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> m = MakeConf(here + '/tests/testfiles/make.conf')
-        >>> m.path = write2
-        >>> m.write()
-
         >>> write = os.tmpnam()
+        >>> write2 = os.tmpnam()
         >>> write3 = os.tmpnam()
         >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> config = {'local_list' : 
+        >>> config = {'local_list' :
         ...           here + '/tests/testfiles/global-overlays.xml',
         ...           'make_conf' : write2,
+        ...           'nocheck'    : True,
         ...           'storage'   : write3}
+
+        >>> here = os.path.dirname(os.path.realpath(__file__))
         >>> a = DB(config)
         >>> config['local_list'] = write
         >>> b = DB(config)
         >>> OUT.color_off()
-        >>> b.add(a.select('wrobel-stable')) #doctest: +ELLIPSIS
-        * Running command "/usr/bin/rsync -rlptDvz --progress --delete --delete-after --timeout=180 --exclude="distfiles/*" --exclude="local/*" --exclude="packages/*" rsync://gunnarwrobel.de/wrobel-stable/* /tmp/file.../wrobel-stable"...
-        >>> b.add(a.select('webapps-experimental')) #doctest: +ELLIPSIS
-        * Running command "/usr/bin/svn co http://svn.gnqs.org/svn/gentoo-webapps-overlay/experimental/ /tmp/file.../webapps-experimental"...
-        >>> c = Overlays([write, ])
-        >>> c.overlays.keys()
-        [u'webapps-experimental', u'wrobel-stable']
-        >>> b.delete(b.select('webapps-experimental'))
-        >>> c = Overlays([write, ])
-        >>> c.overlays.keys()
-        [u'wrobel-stable']
-        
-        >>> m = MakeConf(write2)
-        >>> m.overlays #doctest: +ELLIPSIS
-        ['/usr/portage/local/ebuilds/broken', '/usr/portage/local/ebuilds/testing', '/usr/portage/local/ebuilds/stable', '/usr/portage/local/kolab2', '/usr/portage/local/gentoo-webapps-overlay/experimental', '/usr/portage/local/gentoo-webapps-overlay/production-ready', '/tmp/file.../wrobel-stable']
 
-        >>> os.unlink(write)
+        >>> m = MakeConf(config, b.overlays)
+        >>> m.path = here + '/tests/testfiles/make.conf'
+        >>> m.read()
+
+        >>> m.path = write2
+        >>> m.write()
+
+        # >>> b.add(a.select('wrobel-stable')) #doctest: +ELLIPSIS
+        # * Running command "/usr/bin/rsync -rlptDvz --progress --delete --delete-after --timeout=180 --exclude="distfiles/*" --exclude="local/*" --exclude="packages/*" "rsync://gunnarwrobel.de/wrobel-stable/*" "/tmp/file.../wrobel-stable""...
+        # >>> b.add(a.select('wrobel')) #doctest: +ELLIPSIS
+        # * Running command "/usr/bin/svn co "https://overlays.gentoo.org/svn/dev/wrobel/" "/tmp/file.../wrobel""...
+        # >>> c = Overlays([write, ])
+        # >>> c.overlays.keys()
+        # [u'wrobel', u'wrobel-stable']
+
+        # >>> b.delete(b.select('wrobel'))
+        # >>> c = Overlays([write, ])
+        # >>> c.overlays.keys()
+        # [u'wrobel-stable']
+
+        # >>> m = MakeConf(config, b.overlays)
+        # >>> [i.name for i in m.overlays] #doctest: +ELLIPSIS
+        # [u'wrobel-stable']
+
+        # >>> os.unlink(write)
         >>> os.unlink(write2)
         >>> import shutil
-        >>> shutil.rmtree(write3)
+
+        # >>> shutil.rmtree(write3)
         '''
-        
+
         if overlay.name in self.overlays.keys():
+            make_conf = MakeConf(self.config, self.overlays)
             overlay.delete(self.config['storage'])
             del self.overlays[overlay.name]
             self.write(self.path)
-            make_conf = MakeConf(self.config['make_conf'])
-            make_conf.delete(path([self.config['storage'], overlay.name]))
+            make_conf.delete(overlay)
         else:
             raise Exception('No local overlay named "' + overlay.name + '"!')
 
     def sync(self, overlay_name):
+        '''Synchronize the given overlay.'''
 
         overlay = self.select(overlay_name)
 
@@ -185,31 +205,39 @@ class RemoteDB(Overlays):
 
         paths = [self.path(i) for i in self.urls]
 
-        Overlays.__init__(self, paths)
+        if config['nocheck']:
+            ignore = 2
+        else:
+            ignore = 0
+
+        Overlays.__init__(self, paths, ignore)
 
     def cache(self):
-        ''' 
+        '''
         Copy the remote overlay list to the local cache.
 
+        >>> here = os.path.dirname(os.path.realpath(__file__))
         >>> cache = os.tmpnam()
-        >>> config = {'overlays' : 
-        ...           'http://dev.gentoo.org/~wrobel/layman/global-overlays-test.xml',
-        ...           'cache' : cache}
+        >>> config = {'overlays' :
+        ...           'file://' + here + '/tests/testfiles/global-overlays.xml',
+        ...           'cache' : cache,
+        ...           'nocheck'    : True,
+        ...           'proxy' : None}
         >>> a = RemoteDB(config)
         >>> a.cache()
         >>> b = open(a.path(config['overlays']))
-        >>> b.readlines()[23]
+        >>> b.readlines()[24]
         '      A collection of ebuilds from Gunnar Wrobel [wrobel@gentoo.org].\\n'
-        
+
         >>> b.close()
         >>> os.unlink(a.path(config['overlays']))
 
         >>> a.overlays.keys()
-        [u'webapps-experimental', u'wrobel-stable']
+        [u'wrobel', u'wrobel-stable']
         '''
         for url in self.urls:
 
-            path = self.path(url)
+            mpath = self.path(url)
 
             try:
 
@@ -217,50 +245,52 @@ class RemoteDB(Overlays):
                 olist = urllib.urlopen(url, proxies = self.proxies).read()
 
                 # Create our storage directory if it is missing
-                if not os.path.exists(os.path.dirname(path)):
+                if not os.path.exists(os.path.dirname(mpath)):
                     try:
-                        os.makedirs(os.path.dirname(path))
-                    except OSError, e:
+                        os.makedirs(os.path.dirname(mpath))
+                    except OSError, error:
                         raise OSError('Failed to create layman storage direct'
-                                      + 'ory ' + os.path.dirname(path) + '\nE'
-                                      + 'rror was:' + str(e))
-                
+                                      + 'ory ' + os.path.dirname(mpath) + '\n'
+                                      + 'Error was:' + str(error))
+
                 # Before we overwrite the old cache, check that the downloaded
                 # file is intact and can be parsed
                 try:
                     self.read(olist)
-                except Exception, e:
-                    raise IOError('Failed to parse the overlays list fetched fro' 
-                                  'm ' + url + '\nThis means that the downloaded'
-                                  ' file is somehow corrupt or there was a probl'
-                                  'em with the webserver. Check the content of t'
-                                  'he file. Error was:\n' + str(e))
-                
+                except Exception, error:
+                    raise IOError('Failed to parse the overlays list fetched fr'
+                                  'om ' + url + '\nThis means that the download'
+                                  'ed file is somehow corrupt or there was a pr'
+                                  'oblem with the webserver. Check the content '
+                                  'of the file. Error was:\n' + str(error))
+
                 # Ok, now we can overwrite the old cache
                 try:
-                    out_file = open(path, 'w')
+                    out_file = open(mpath, 'w')
                     out_file.write(olist)
                     out_file.close()
 
-                except Exception, e:
-                    raise IOError('Failed to temporarily cache overlays list in ' 
-                                  + path + '\nError was:\n' + str(e))
+                except Exception, error:
+                    raise IOError('Failed to temporarily cache overlays list in'
+                                  ' ' + mpath + '\nError was:\n' + str(error))
 
 
-            except IOError, e:
-                OUT.warn('Failed to update the overlay list from: ' 
-                         + url + '\nError was:\n' + str(e))
+            except IOError, error:
+                OUT.warn('Failed to update the overlay list from: '
+                         + url + '\nError was:\n' + str(error))
 
             try:
                 # Finally parse the contents of the cache
-                self.read_file(path)
-            except IOError, e:
-                OUT.warn('Failed to read a cached version of the overlay list fr' 
-                         'om ' + url + '. You probably did not download the file'
-                         ' before. The corresponding entry in your layman.cfg fi'
-                         'le will be disregarded.\nError was:\n' + str(e))
+                self.read_file(mpath)
+            except IOError, error:
+                OUT.warn('Failed to read a cached version of the overlay list f'
+                         'rom ' + url + '. You probably did not download the fi'
+                         'le before. The corresponding entry in your layman.cfg'
+                         ' file will be disregarded.\nError was:\n' + str(error)
+                         )
 
     def path(self, url):
+        '''Return a unique file name for the url.'''
 
         base = self.config['cache']
 
@@ -283,62 +313,101 @@ class MakeConf:
     >>> import md5
     >>> write = os.tmpnam()
     >>> here = os.path.dirname(os.path.realpath(__file__))
-    >>> a = MakeConf(here + '/tests/testfiles/make.conf')
+    >>> config = {'local_list' :
+    ...           here + '/tests/testfiles/global-overlays.xml',
+    ...           'make_conf' : here + '/tests/testfiles/make.conf',
+    ...           'nocheck'    : True,
+    ...           'storage'   : '/usr/portage/local/layman'}
+    >>> b = DB(config)
+    >>> a = MakeConf(config, b.overlays)
     >>> o_md5 = str(md5.md5(open(here + '/tests/testfiles/make.conf').read()).hexdigest())
     >>> a.path = write
-    >>> a.add('test   ')
-    >>> a.delete('/usr/portage/local/gentoo-webapps-overlay/production-ready')
-    >>> a.add('/usr/portage/local/gentoo-webapps-overlay/production-ready')
-    >>> a.delete('test   ')
+    >>> a.add(b.overlays['wrobel-stable'])
+    >>> [i.name for i in a.overlays]
+    [u'wrobel-stable', u'wrobel-stable']
+    >>> a.add(b.overlays['wrobel'])
+    >>> [i.name for i in a.overlays]
+    [u'wrobel', u'wrobel-stable', u'wrobel-stable']
+    >>> a.delete(b.overlays['wrobel-stable'])
+    >>> [i.name for i in a.overlays]
+    [u'wrobel']
+    >>> a.add(b.overlays['wrobel-stable'])
+    >>> [i.name for i in a.overlays]
+    [u'wrobel', u'wrobel-stable']
+    >>> a.delete(b.overlays['wrobel'])
     >>> n_md5 = str(md5.md5(open(write).read()).hexdigest())
     >>> o_md5 == n_md5
     True
-    >>> #os.unlink(write)
+    >>> os.unlink(write)
     '''
 
     my_re = re.compile('PORTDIR_OVERLAY\s*=\s*"([^"]*)"')
 
-    def __init__(self, path):
-        self.path = path
+    def __init__(self, config, overlays):
+
+        self.path = config['make_conf']
+        self.storage = config['storage']
+        self.data = ''
+        self.db = overlays
+        self.overlays = []
+        self.extra = []
 
         self.read()
 
-    def add(self, overlay_path):
+    def add(self, overlay):
         '''
         Add an overlay to make.conf.
 
         >>> write = os.tmpnam()
         >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> a = MakeConf(here + '/tests/testfiles/make.conf')
+        >>> config = {'local_list' :
+        ...           here + '/tests/testfiles/global-overlays.xml',
+        ...           'make_conf' : here + '/tests/testfiles/make.conf',
+        ...           'nocheck'    : True,
+        ...           'storage'   : '/usr/portage/local/layman'}
+        >>> c = DB(config)
+        >>> a = MakeConf(config, c.overlays)
         >>> a.path = write
-        >>> a.add('test   ')
-        >>> b = MakeConf(write)
-        >>> b.overlays
-        ['/usr/portage/local/ebuilds/broken', '/usr/portage/local/ebuilds/testing', '/usr/portage/local/ebuilds/stable', '/usr/portage/local/kolab2', '/usr/portage/local/gentoo-webapps-overlay/experimental', '/usr/portage/local/gentoo-webapps-overlay/production-ready', 'test']
-        
+        >>> a.add(c.select('wrobel'))
+        >>> config['make_conf'] = write
+        >>> b = MakeConf(config, c.overlays)
+        >>> [i.name for i in b.overlays]
+        [u'wrobel', u'wrobel-stable']
+        >>> b.extra
+        ['/usr/portage/local/ebuilds/testing', '/usr/portage/local/ebuilds/stable', '/usr/portage/local/kolab2', '/usr/portage/local/gentoo-webapps-overlay/experimental', '/usr/portage/local/gentoo-webapps-overlay/production-ready']
+
         >>> os.unlink(write)
         '''
-        self.overlays.append(path(overlay_path.strip()))
+        self.overlays.append(overlay)
         self.write()
 
-    def delete(self, overlay_path):
+    def delete(self, overlay):
         '''
         Delete an overlay from make.conf.
 
         >>> write = os.tmpnam()
         >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> a = MakeConf(here + '/tests/testfiles/make.conf')
+        >>> config = {'local_list' :
+        ...           here + '/tests/testfiles/global-overlays.xml',
+        ...           'make_conf' : here + '/tests/testfiles/make.conf',
+        ...           'nocheck'    : True,
+        ...           'storage'   : '/usr/portage/local/layman'}
+        >>> c = DB(config)
+        >>> a = MakeConf(config, c.overlays)
         >>> a.path = write
-        >>> a.delete('/usr/portage/local/ebuilds/broken')
-        >>> b = MakeConf(write)
-        >>> b.overlays
+        >>> a.delete(c.select('wrobel-stable'))
+        >>> config['make_conf'] = write
+        >>> b = MakeConf(config, c.overlays)
+        >>> [i.name for i in b.overlays]
+        []
+        >>> b.extra
         ['/usr/portage/local/ebuilds/testing', '/usr/portage/local/ebuilds/stable', '/usr/portage/local/kolab2', '/usr/portage/local/gentoo-webapps-overlay/experimental', '/usr/portage/local/gentoo-webapps-overlay/production-ready']
-        
+
         >>> os.unlink(write)
         '''
-        self.overlays = [path(i) 
+        self.overlays = [i
                          for i in self.overlays
-                         if path(i) != path(overlay_path.strip())]
+                         if i.name != overlay.name]
         self.write()
 
     def read(self):
@@ -346,28 +415,52 @@ class MakeConf:
         Read the list of registered overlays from /etc/make.conf.
 
         >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> a = MakeConf(here + '/tests/testfiles/make.conf')
-        >>> a.overlays
-        ['/usr/portage/local/ebuilds/broken', '/usr/portage/local/ebuilds/testing', '/usr/portage/local/ebuilds/stable', '/usr/portage/local/kolab2', '/usr/portage/local/gentoo-webapps-overlay/experimental', '/usr/portage/local/gentoo-webapps-overlay/production-ready']
+        >>> config = {'local_list' :
+        ...           here + '/tests/testfiles/global-overlays.xml',
+        ...           'make_conf' : here + '/tests/testfiles/make.conf',
+        ...           'nocheck'    : True,
+        ...           'storage'   : '/usr/portage/local/layman'}
+        >>> c = DB(config)
+        >>> a = MakeConf(config, c.overlays)
+        >>> [i.name for i in a.overlays]
+        [u'wrobel-stable']
+        >>> a.extra
+        ['/usr/portage/local/ebuilds/testing', '/usr/portage/local/ebuilds/stable', '/usr/portage/local/kolab2', '/usr/portage/local/gentoo-webapps-overlay/experimental', '/usr/portage/local/gentoo-webapps-overlay/production-ready']
         '''
         if os.path.isfile(self.path):
             self.content()
 
             overlays = self.my_re.search(self.data)
-        
+
             if not overlays:
                 raise Exception('Did not find a PORTDIR_OVERLAY entry in file ' +
                                 self.path +'! Did you specify the correct file?')
 
-            self.overlays = [i.strip() 
-                             for i in overlays.group(1).split('\n') 
-                             if i.strip()]
+            overlays = [i.strip()
+                        for i in overlays.group(1).split('\n')
+                        if i.strip()]
+
+            for i in overlays:
+                if i[:len(self.storage)] == self.storage:
+                    oname = os.path.basename(i)
+                    if  oname in self.db.keys():
+                        self.overlays.append(self.db[oname])
+                    else:
+                        # These are additional overlays that we dont know
+                        # anything about. The user probably added them manually
+                        self.extra.append(i)
+                else:
+                    # These are additional overlays that we dont know anything
+                    # about. The user probably added them manually
+                    self.extra.append(i)
+
+
         else:
             self.overlays = []
             self.data     = 'PORTDIR_OVERLAY="\n"\n'
 
-        self.overlays = [i for i in self.overlays 
-                         if (i != '$PORTDIR_OVERLAY' 
+        self.extra = [i for i in self.extra
+                         if (i != '$PORTDIR_OVERLAY'
                              and i != '${PORTDIR_OVERLAY}')]
 
     def write(self):
@@ -376,21 +469,45 @@ class MakeConf:
 
         >>> write = os.tmpnam()
         >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> a = MakeConf(here + '/tests/testfiles/make.conf')
+        >>> config = {'local_list' :
+        ...           here + '/tests/testfiles/global-overlays.xml',
+        ...           'make_conf' : here + '/tests/testfiles/make.conf',
+        ...           'nocheck'    : True,
+        ...           'storage'   : '/usr/portage/local/layman'}
+        >>> c = DB(config)
+        >>> a = MakeConf(config, c.overlays)
         >>> a.path = write
         >>> a.write()
-        >>> b = MakeConf(write)
-        >>> b.overlays
-        ['/usr/portage/local/ebuilds/broken', '/usr/portage/local/ebuilds/testing', '/usr/portage/local/ebuilds/stable', '/usr/portage/local/kolab2', '/usr/portage/local/gentoo-webapps-overlay/experimental', '/usr/portage/local/gentoo-webapps-overlay/production-ready']
-        
+        >>> config['make_conf'] = write
+        >>> b = MakeConf(config, c.overlays)
+        >>> [i.name for i in b.overlays]
+        [u'wrobel-stable']
+        >>> b.extra
+        ['/usr/portage/local/ebuilds/testing', '/usr/portage/local/ebuilds/stable', '/usr/portage/local/kolab2', '/usr/portage/local/gentoo-webapps-overlay/experimental', '/usr/portage/local/gentoo-webapps-overlay/production-ready']
+
         >>> os.unlink(write)
         '''
+        def prio_sort(a, b):
+            '''Sort by priority.'''
+            if a.priority < b.priority:
+                return -1
+            elif a.priority > b.priority:
+                return 1
+            return 0
+
+        self.overlays.sort(prio_sort)
+
+        paths = []
+        for i in self.overlays:
+            paths.append(path((self.storage, i.name, )))
+
         overlays = 'PORTDIR_OVERLAY="$PORTDIR_OVERLAY\n'
-        overlays += '\n'.join(self.overlays)
+        overlays += '\n'.join(paths) + '\n'
+        overlays += '\n'.join(self.extra)
         overlays += '"'
 
         content = self.my_re.sub(overlays, self.data)
-        
+
         if not self.my_re.search(content):
             raise Exception('Ups, failed to set a proper PORTDIR_OVERLAY entry '
                             'in file ' + self.path +'! Did not overwrite the fi'
@@ -398,14 +515,14 @@ class MakeConf:
 
         try:
             make_conf = open(self.path, 'w')
-            
-            self.content = make_conf.write(content)
+
+            make_conf.write(content)
 
             make_conf.close()
 
-        except Exception, e:
-            raise Exception('Failed to read "' + self.path + '".\nError was:\n'  
-                            + str(e))
+        except Exception, error:
+            raise Exception('Failed to read "' + self.path + '".\nError was:\n'
+                            + str(error))
 
     def content(self):
         '''
@@ -413,14 +530,20 @@ class MakeConf:
         '''
         try:
             make_conf = open(self.path)
-            
+
             self.data = make_conf.read()
 
             make_conf.close()
 
-        except Exception, e:
+        except Exception, error:
             raise Exception('Failed to read "' + self.path + '".\nError was:\n'
-                            + str(e))
+                            + str(error))
+
+#===============================================================================
+#
+# Testing
+#
+#-------------------------------------------------------------------------------
 
 if __name__ == '__main__':
     import doctest, sys
