@@ -16,7 +16,7 @@
 #
 '''Main handler for overlays.'''
 
-__version__ = "$Id: overlay.py 240 2006-09-06 07:45:11Z wrobel $"
+__version__ = "$Id: overlay.py 252 2006-09-23 07:31:40Z wrobel $"
 
 #===============================================================================
 #
@@ -30,6 +30,7 @@ from   layman.overlays.bzr       import BzrOverlay
 from   layman.overlays.darcs     import DarcsOverlay
 from   layman.overlays.git       import GitOverlay
 from   layman.overlays.mercurial import MercurialOverlay
+from   layman.overlays.cvs       import CvsOverlay
 from   layman.overlays.svn       import SvnOverlay
 from   layman.overlays.rsync     import RsyncOverlay
 from   layman.overlays.tar       import TarOverlay
@@ -43,6 +44,7 @@ from   layman.debug              import OUT
 #-------------------------------------------------------------------------------
 
 OVERLAY_TYPES = {'git'       : GitOverlay,
+                 'cvs'       : CvsOverlay,
                  'svn'       : SvnOverlay,
                  'rsync'     : RsyncOverlay,
                  'tar'       : TarOverlay,
