@@ -15,8 +15,9 @@
 #             Gunnar Wrobel <wrobel@gentoo.org>
 #             Andres Loeh <kosmikus@gentoo.org>
 #
+''' Darcs overlay support.'''
 
-__version__ = "$Id$"
+__version__ = "$Id: darcs.py 236 2006-09-05 20:39:37Z wrobel $"
 
 #===============================================================================
 #
@@ -27,8 +28,6 @@ __version__ = "$Id$"
 from   layman.utils             import path
 from   layman.overlays.overlay  import Overlay
 
-from   layman.debug             import OUT
-
 #===============================================================================
 #
 # Class BzrOverlay
@@ -40,22 +39,26 @@ class DarcsOverlay(Overlay):
 
     type = 'Darcs'
 
-    binary_command  = '/usr/bin/darcs' 
-    
+    binary_command  = '/usr/bin/darcs'
+
     def add(self, base):
+        '''Add overlay.'''
 
         self.supported()
 
-        return self.cmd(self.binary_command + ' get --partial ' + self.src + '/ ' + \
-                        path([base, self.name]))
+        return self.cmd(self.binary_command + ' get --partial "' + self.src +
+                        '/" "' + path([base, self.name]) + '"')
 
     def sync(self, base):
+        '''Sync overlay.'''
 
         self.supported()
 
-        return self.cmd('cd ' + path([base, self.name]) + ' && ' + \
-                        self.binary_command + ' pull --all ' + self.src)
+        return self.cmd('cd "' + path([base, self.name]) + '" && ' +
+                        self.binary_command + ' pull --all "' + self.src + '"')
 
     def supported(self):
+        '''Overlay type supported?'''
 
-        return Overlay.supported(self, [(self.binary_command,  'darcs', 'dev-util/darcs'),])
+        return Overlay.supported(self, [(self.binary_command,  'darcs',
+                                         'dev-util/darcs'),])
